@@ -19,9 +19,5 @@
 Various file network services.
 '''
 
-# publish the HttpUploader class
-from gnome_lirc_properties.net.HttpUploader import HttpUploader
-
-# publish update services
 # pylint: disable-msg=W0401
-from gnome_lirc_properties.net.updates import *
+from gnome_lirc_properties.net.services import *
